import MCF_Array from './array'
import MCF_Boolean from './boolean'
import MCF_Enum from './enum'
import MCF_Number from './number'
import MCF_String from './string'



export default class MCF_TypeFactory {
  static buildDefinedObject(definedObject) {
    const objectDefinition = definedObject.getDefinition()
    const fields = objectDefinition.fields
    const dictionary = {}
    for (const field in fields) {
      switch (fields[field]['TYPE']) {
      case 'array':
        dictionary[field] = new MCF_Array(fields[field])
        break
      case 'boolean':
        dictionary[field] = new MCF_Boolean(fields[field])
        break
      case 'enum':
        dictionary[field] = new MCF_Enum(fields[field])
        break
      case 'number':
        dictionary[field] = new MCF_Number(fields[field])
        break
      case 'string':
        dictionary[field] = new MCF_String(fields[field])
        break
      default:
        throw new Error(`MCF-Objects ==> The object type ${fields[field]['TYPE']} does not exist. Check the field definition in the object definition ${objectDefinition}`)
      }
    }
    return dictionary
  }
}
